#!/usr/bin/python

import subprocess
import sys

repair = sys.argv[1]

cluster_sizes = [25]

num_edits = [30]

print "entering Jamie wrapper"

for i in cluster_sizes:
	for j in num_edits:
		subprocess.call(["./composer.py","-g", repair, "-n", str(i), "-k", str(j), "-o", "output."+str(i)+"."+str(j)])

